<?php
/**
 * JCorner class file.
 *
 * @author Stefan Volkmar <volkmar_yii@email.de>
 * @version 1.1
 * @license BSD
 */

/**
 * This widget encapsulates the corner plugin for jQuery for creating rounded (or other styled) corners on elements.
 * ({@link http://jquery.malsup.com/corner/}).
 *
 * @author Stefan Volkmar <volkmar_yii@email.de>
 */

class JCorner extends CWidget
{
    /**
	 * @var boolean decide if you want create the HTML-Element or only create the javascript piece
     * Defaults to TRUE.
	 */
	public $renderElement=true;
	/**
	 * @var string the argument for the function
	 */
	public $argument;

	/**
	 * @var string the name of the container element.
     * Defaults to 'div'.
	 */
	public $tagName='div';

	/**
	 * @var array the HTML attributes that should be rendered in the HTML tag
	 */
	public $htmlOptions=array();

	/**
	 * Renders the open tag of the Html element.
	 * This method also registers the necessary javascript code.
	 */
	public function init()
	{
		$id=$this->getId();
		if (isset($this->htmlOptions['id']))
			$id = $this->htmlOptions['id'];
		else
			$this->htmlOptions['id']=$id;

      	$baseUrl = CHtml::asset(dirname(__FILE__).DIRECTORY_SEPARATOR.'assets');

        $JsFile = (YII_DEBUG)?"/js/jquery.corner.js":"/js/jquery.corner.min.js";

        $selector="";
        if ($id)
            $selector="#$id";
        elseif (isset($this->htmlOptions['class'])){
            $selector=".".$this->htmlOptions['class'];
        }

        if ($selector === '')
            throw new CException('The "id" or "class" - attribute of the element must be set!');

  		Yii::app()->getClientScript()
            ->registerPackage('metadata')
            ->registerScriptFile($baseUrl.$JsFile)
            ->registerScript(__CLASS__.'#'.$id ,"$('$selector').corner('".$this->argument."');");

        if ($this->renderElement)
            echo CHtml::openTag($this->tagName,$this->htmlOptions)."\n";
	}

	/**
	 * Renders the close tag of the element.
	 */
	public function run(){
	    if ($this->renderElement)
		    echo CHtml::closeTag($this->tagName);
	}
}